Crate mq_view

Crate mq_view 

A library for rendering Markdown documents with syntax highlighting.

This crate provides functionality to render Markdown content with rich text formatting and syntax highlighting for code blocks using tree-sitter.

Examples

use mq_view::render_markdown_to_string;
use mq_markdown::Markdown;

let markdown: Markdown = "# Hello\n\n```rust\nfn main() {}\n```".parse().unwrap();
let rendered = render_markdown_to_string(&markdown).unwrap();
println!("{}", rendered);

Structs

RenderConfig
Configuration for rendering markdown
SyntaxHighlighter
Syntax highlighter supporting various programming languages and HTML.

Functions

render_markdown
Render a Markdown document to a writer with syntax highlighting and rich text formatting.
render_markdown_to_string
Render a Markdown document to a String with syntax highlighting and rich text formatting.
render_markdown_with_config
Render a Markdown document to a writer with custom configuration.